=======
History
=======

0.1.0 (2017-07-27)
------------------

* First release on PyPI.


0.2.0 (2017-08-12)
------------------

* Added ``PIL.ImageEnhance`` and ``PIL.ImageFilter`` built-in support
* Enabled auto color generation for unit colors


0.3.0 (2017-08-17)
------------------

* Dropped shadow support for units
* Added outline support for units
* Made unit's font config as a separate class


0.4.0 (2017-09-14)
------------------

* Added ability to add watermarks to images 


